@@ -1,3 +1,3 @@
 from .kadena_sdk import KadenaSdk
 from .key_pair import KeyPair
-from .signing import hash_and_sign
\ No newline at end of file
+from .crypto_lib import hash_and_sign, blake_hash
\ No newline at end of file
